seaduck.ocedata.RelCoord and subclasses
---------------------------------------

.. autoclass:: seaduck.ocedata.RelCoord
   :members:
   :undoc-members:
   :show-inheritance:

Subclasses
----------

.. autoclass:: seaduck.ocedata.HRel

.. autoclass:: seaduck.ocedata.VRel

.. autoclass:: seaduck.ocedata.VLinRel

.. autoclass:: seaduck.ocedata.VlRel

.. autoclass:: seaduck.ocedata.VlLinRel

.. autoclass:: seaduck.ocedata.TRel

.. autoclass:: seaduck.ocedata.TLinRel
